# gLEC - Global Landscape Elevation Connectivity

This package calculates Landscape Elevation Connectivity (LEC) on triangular irregular meshes, including global meshes.

It uses a max_fuel function to determine how far away from a point the connectivity should be calculated.
